@extends('themes.base.layout')
@section('title', trans('admin.create_user'))

@section('breadcrumb')
    <div class="breadcrumb">
        <div class="container">
            <ol class="breadcrumb">
                <li><a href="{{ route('home') }}"><i class="fa fa-fw fa-home"></i></a></li>
                <li><a href="{{ route('admin') }}">@lang('navigation.breadcrumb.admin')</a></li>
                <li><a href="{{ route('users.index') }}">@lang('navigation.breadcrumb.users')</a></li>
                <li class="active">@lang('navigation.breadcrumb.create_user')</li>
            </ol>
        </div>
    </div>
@endsection

@section('content')
    <div class="container">
        <div class="row">
            <div class="col-xs-12">
                <h1>@lang('admin.create_user_title')</h1>
                <p>@lang('admin.create_user_intro')</p>
                <hr/>

                {!! Form::open(['route' => 'users.store', 'method' => 'POST']) !!}
                <div class="row">
                    <div class="col-sm-6">
                        <div class="form-group{{ $errors->has('name') ? ' has-error' : '' }}">
                            {!! Form::label('name', trans('forms.name_label'), ['class' => 'control-label']) !!}
                            {!! Form::text('name', old('name'), ['class' => 'form-control']) !!}

                            @if ($errors->has('name'))
                                <span class="help-block">
                                    <strong>{{ $errors->first('name') }}</strong>
                                </span>
                            @endif
                        </div>
                    </div>

                    <div class="col-sm-6">
                        <div class="form-group{{ $errors->has('email') ? ' has-error' : '' }}">
                            {!! Form::label('email', trans('forms.email_label'), ['class' => 'control-label']) !!}
                            {!! Form::text('email', old('email'), ['class' => 'form-control']) !!}

                            @if ($errors->has('email'))
                                <span class="help-block">
                                    <strong>{{ $errors->first('email') }}</strong>
                                </span>
                            @endif
                        </div>
                    </div>
                </div>

                <div class="row">
                    <div class="col-sm-6">
                        <div class="form-group{{ $errors->has('password') ? ' has-error' : '' }}">
                            {!! Form::label('password', trans('forms.password_label'), ['class' => 'control-label']) !!}
                            {!! Form::password('password', ['class' => 'form-control']) !!}

                            @if ($errors->has('password'))
                                <span class="help-block">
                                    <strong>{{ $errors->first('password') }}</strong>
                                </span>
                            @endif
                        </div>
                    </div>

                    <div class="col-sm-6">
                        <div class="form-group{{ $errors->has('password_confirmation') ? ' has-error' : '' }}">
                            {!! Form::label('password_confirmation', trans('forms.password_confirm_label'), ['class' => 'control-label']) !!}
                            {!! Form::password('password_confirmation', ['class' => 'form-control']) !!}

                            @if ($errors->has('password_confirmation'))
                                <span class="help-block">
                                    <strong>{{ $errors->first('password_confirmation') }}</strong>
                                </span>
                            @endif
                        </div>
                    </div>
                </div>

                <div class="checkbox">
                    <label>
                        <input type="checkbox" name="is_admin">
                        <strong>@lang('forms.admin_user_label')</strong>
                    </label>
                </div>

                <div class="checkbox">
                    <label>
                        <input type="checkbox" name="can_create_albums">
                        <strong>@lang('forms.can_create_albums_label')</strong>
                    </label>
                </div>

                <div class="form-actions">
                    <a href="{{ route('users.index') }}" class="btn btn-default">@lang('forms.cancel_action')</a>
                    <button type="submit" class="btn btn-success"><i class="fa fa-fw fa-check"></i> @lang('forms.create_action')</button>
                </div>
                {!! Form::close() !!}
            </div>
        </div>
    </div>
@endsection