@extends('themes.base.layout')
@section('title', trans('admin.edit_storage', ['storage_name' => $storage->name]))

@section('breadcrumb')
    <div class="breadcrumb">
        <div class="container">
            <ol class="breadcrumb">
                <li><a href="{{ route('home') }}"><i class="fa fa-fw fa-home"></i></a></li>
                <li><a href="{{ route('admin') }}">@lang('navigation.breadcrumb.admin')</a></li>
                <li><a href="{{ route('storage.index') }}">@lang('navigation.breadcrumb.storage')</a></li>
                <li class="active">@lang('navigation.breadcrumb.edit_storage')</li>
            </ol>
        </div>
    </div>
@endsection

@section('content')
    <div class="container">
        <div class="row">
            <div class="col-xs-12">
                <h1>@yield('title')</h1>
                <p>@lang('admin.edit_storage_intro', ['storage_name' => $storage->name])</p>
                <hr/>

                {!! Form::model($storage, ['route' => ['storage.update', $storage->id], 'method' => 'PUT']) !!}
                <div class="form-group{{ $errors->has('name') ? ' has-error' : '' }}">
                    {!! Form::label('name', trans('forms.name_label'), ['class' => 'control-label']) !!}
                    {!! Form::text('name', old('name'), ['class' => 'form-control']) !!}

                    @if ($errors->has('name'))
                        <span class="help-block">
                            <strong>{{ $errors->first('name') }}</strong>
                        </span>
                    @endif
                </div>

                <div class="checkbox">
                    <label>
                        <input type="checkbox" name="is_default"@if ($storage->is_default) checked="checked"@endif>
                        <strong>@lang('forms.default_storage_label')</strong>
                    </label>
                </div>

                <div class="checkbox">
                    <label>
                        <input type="checkbox" name="is_active"@if ($storage->is_active) checked="checked"@endif>
                        <strong>@lang('forms.storage_active_label')</strong>
                    </label>
                </div>

                @if ($storage->source == 'OpenStackSource')
                    <hr/>
                    @include(Theme::viewName('partials.admin_storages_openstack_options'))
                @endif

                @if ($storage->source == 'AmazonS3Source')
                    <hr/>
                    @include(Theme::viewName('partials.admin_storages_amazon_s3_options'))
                @endif

                @if ($storage->source == 'RackspaceSource')
                    <hr/>
                    @include(Theme::viewName('partials.admin_storages_rackspace_options'))
                @endif

                <div class="form-actions">
                    <a href="{{ route('storage.index') }}" class="btn btn-default">@lang('forms.cancel_action')</a>
                    <button type="submit" class="btn btn-success"><i class="fa fa-fw fa-check"></i> @lang('forms.save_action')</button>
                </div>
                {!! Form::close() !!}
            </div>
        </div>
    </div>
@endsection

@push('scripts')
<script type="text/javascript">
    var viewModel = new StorageLocationsViewModel();
    ko.applyBindings(viewModel);
</script>
@endpush