@extends('themes.base.layout')
@section('title', trans('admin.edit_user_title', ['name' => $user->name]))

@section('breadcrumb')
    <div class="breadcrumb">
        <div class="container">
            <ol class="breadcrumb">
                <li><a href="{{ route('home') }}"><i class="fa fa-fw fa-home"></i></a></li>
                <li><a href="{{ route('admin') }}">@lang('navigation.breadcrumb.admin')</a></li>
                <li><a href="{{ route('users.index') }}">@lang('navigation.breadcrumb.users')</a></li>
                <li class="active">@lang('navigation.breadcrumb.edit_user')</li>
            </ol>
        </div>
    </div>
@endsection

@section('content')
    <div class="container">
        <div class="row">
            <div class="col-xs-12">
                <h1>@yield('title')</h1>
                <p>@lang('admin.edit_user_intro')</p>
                <hr/>

                {!! Form::model($user, ['route' => ['users.update', $user->id], 'method' => 'PUT']) !!}
                <div>
                    {{-- Nav tabs --}}
                    <ul class="nav nav-tabs" role="tablist">
                        @include(Theme::viewName('partials.tab'), ['active_tab' => 'details', 'tab_name' => 'details', 'tab_icon' => 'info-circle', 'tab_text' => trans('admin.user_details_tab')])
                        @include(Theme::viewName('partials.tab'), ['active_tab' => 'details', 'tab_name' => 'groups', 'tab_icon' => 'users', 'tab_text' => trans('admin.user_groups_tab')])
                    </ul>

                    {{-- Tab panes --}}
                    <div class="tab-content">
                        {{-- Details --}}
                        <div role="tabpanel" class="tab-pane active" id="details-tab">
                            <div class="row">
                                <div class="col-sm-6">
                                    <div class="form-group{{ $errors->has('name') ? ' has-error' : '' }}">
                                        {!! Form::label('name', trans('forms.name_label'), ['class' => 'control-label']) !!}
                                        {!! Form::text('name', old('name'), ['class' => 'form-control']) !!}

                                        @if ($errors->has('name'))
                                            <span class="help-block">
                                                <strong>{{ $errors->first('name') }}</strong>
                                            </span>
                                        @endif
                                    </div>
                                </div>

                                <div class="col-sm-6">
                                    <div class="form-group{{ $errors->has('email') ? ' has-error' : '' }}">
                                        {!! Form::label('email', trans('forms.email_label'), ['class' => 'control-label']) !!}
                                        {!! Form::text('email', old('email'), ['class' => 'form-control']) !!}

                                        @if ($errors->has('email'))
                                            <span class="help-block">
                                                <strong>{{ $errors->first('email') }}</strong>
                                            </span>
                                        @endif
                                    </div>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col-sm-6">
                                    <div class="form-group{{ $errors->has('password') ? ' has-error' : '' }}">
                                        {!! Form::label('password', trans('forms.password_label'), ['class' => 'control-label']) !!}
                                        {!! Form::password('password', ['class' => 'form-control']) !!}

                                        @if ($errors->has('password'))
                                            <span class="help-block">
                                                <strong>{{ $errors->first('password') }}</strong>
                                            </span>
                                        @endif
                                    </div>
                                </div>

                                <div class="col-sm-6">
                                    <div class="form-group{{ $errors->has('password_confirmation') ? ' has-error' : '' }}">
                                        {!! Form::label('password_confirmation', trans('forms.password_confirm_label'), ['class' => 'control-label']) !!}
                                        {!! Form::password('password_confirmation', ['class' => 'form-control']) !!}

                                        @if ($errors->has('password_confirmation'))
                                            <span class="help-block">
                                                <strong>{{ $errors->first('password_confirmation') }}</strong>
                                            </span>
                                        @endif
                                    </div>
                                </div>
                            </div>

                            <div class="checkbox">
                                <label>
                                    <input type="checkbox" name="is_admin"@if ($user->is_admin) checked="checked"@endif>
                                    <strong>@lang('forms.admin_user_label')</strong>
                                </label>
                            </div>

                            <div class="checkbox">
                                <label>
                                    <input type="checkbox" name="can_create_albums"@if ($user->can_create_albums) checked="checked"@endif>
                                    <strong>@lang('forms.can_create_albums_label')</strong>
                                </label>
                            </div>

                            @if (!$user->is_activated)
                                <div class="checkbox">
                                    <label>
                                        <input type="checkbox" name="is_activated">
                                        <strong>@lang('forms.activate_user_label')</strong>
                                    </label>
                                </div>
                            @endif
                        </div>

                        {{-- Groups --}}
                        <div role="tabpanel" class="tab-pane" id="groups-tab">
                            @if ($groups->count() > 0)
                                <p style="margin-bottom: 20px;">@lang('admin.user_groups_list_select', ['name' => $user->name])</p>

                                @foreach ($groups as $group)
                                    <div class="checkbox">
                                        <label>
                                            <input type="checkbox" name="user_group_id[]" value="{{ $group->id }}"@if (in_array($group->id, $users_groups)) checked="checked"@endif>
                                            <strong>{{ $group->name }}</strong>
                                        </label>
                                    </div>
                                @endforeach
                            @else
                            @endif
                        </div>
                    </div>

                    <div class="form-actions" style="margin-top: 20px;">
                        <a href="{{ route('users.index') }}" class="btn btn-default">@lang('forms.cancel_action')</a>
                        <button type="submit" class="btn btn-success"><i class="fa fa-fw fa-check"></i> @lang('forms.save_action')</button>
                    </div>
                </div>
                {!! Form::close() !!}
            </div>
        </div>
    </div>
@endsection